pub struct Message {
pub role: Role,
pub content: Vec<Content>,
pub tool_call_id: Option<String>,
}Expand description
A message in a conversation.
Fields
role: RoleRole of the message sender.
content: Vec<Content>Content blocks in this message.
tool_call_id: Option<String>ID of the tool call this message responds to (for Tool role).
Implementations
Sourceimpl Message
impl Message
Sourcepub fn assistant(text: impl Into<String>) -> Self
pub fn assistant(text: impl Into<String>) -> Self
Creates an assistant message with text content.
Sourcepub fn tool_result(
call_id: impl Into<String>,
result: impl Into<String>,
) -> Self
pub fn tool_result( call_id: impl Into<String>, result: impl Into<String>, ) -> Self
Creates a tool result message.
Sourcepub fn tool_call_id(&self) -> Option<&str>
pub fn tool_call_id(&self) -> Option<&str>
Returns the tool call ID if this is a tool result message.
Sourcepub fn tool_calls(&self) -> impl Iterator<Item = &ToolCall>
pub fn tool_calls(&self) -> impl Iterator<Item = &ToolCall>
Returns an iterator over tool calls in this message.